summaryrefslogtreecommitdiffstats
path: root/kopete/kopete/chatwindow/kopetechatwindow.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/kopete/chatwindow/kopetechatwindow.cpp')
-rw-r--r--kopete/kopete/chatwindow/kopetechatwindow.cpp50
1 files changed, 25 insertions, 25 deletions
diff --git a/kopete/kopete/chatwindow/kopetechatwindow.cpp b/kopete/kopete/chatwindow/kopetechatwindow.cpp
index a330dc43..5d1d2d11 100644
--- a/kopete/kopete/chatwindow/kopetechatwindow.cpp
+++ b/kopete/kopete/chatwindow/kopetechatwindow.cpp
@@ -287,7 +287,7 @@ void KopeteChatWindow::slotTabContextMenu( TQWidget *tab, const TQPoint &pos )
{
m_popupView = static_cast<ChatView*>( tab );
- KPopupMenu *popup = new KPopupMenu;
+ TDEPopupMenu *popup = new TDEPopupMenu;
popup->insertTitle( KStringHandler::rsqueeze( m_popupView->caption() ) );
actionContactMenu->plug( popup );
@@ -309,42 +309,42 @@ ChatView *KopeteChatWindow::activeView()
void KopeteChatWindow::initActions(void)
{
- KActionCollection *coll = actionCollection();
+ TDEActionCollection *coll = actionCollection();
createStandardStatusBarAction();
- chatSend = new KAction( i18n( "&Send Message" ), TQString::fromLatin1( "mail_send" ), TQKeySequence(Key_Return) ,
+ chatSend = new TDEAction( i18n( "&Send Message" ), TQString::fromLatin1( "mail_send" ), TQKeySequence(Key_Return) ,
TQT_TQOBJECT(this), TQT_SLOT( slotSendMessage() ), coll, "chat_send" );
chatSend->setEnabled( false );
KStdAction::save ( TQT_TQOBJECT(this), TQT_SLOT(slotChatSave()), coll );
KStdAction::print ( TQT_TQOBJECT(this), TQT_SLOT(slotChatPrint()), coll );
- KAction* quitAction = KStdAction::quit ( TQT_TQOBJECT(this), TQT_SLOT(close()), coll );
+ TDEAction* quitAction = KStdAction::quit ( TQT_TQOBJECT(this), TQT_SLOT(close()), coll );
quitAction->setText( i18n("Close All Chats") );
tabClose = KStdAction::close ( TQT_TQOBJECT(this), TQT_SLOT(slotChatClosed()), coll, "tabs_close" );
- tabRight=new KAction( i18n( "&Activate Next Tab" ), 0, KStdAccel::tabNext(),
+ tabRight=new TDEAction( i18n( "&Activate Next Tab" ), 0, TDEStdAccel::tabNext(),
TQT_TQOBJECT(this), TQT_SLOT( slotNextTab() ), coll, "tabs_right" );
- tabLeft=new KAction( i18n( "&Activate Previous Tab" ), 0, KStdAccel::tabPrev(),
+ tabLeft=new TDEAction( i18n( "&Activate Previous Tab" ), 0, TDEStdAccel::tabPrev(),
TQT_TQOBJECT(this), TQT_SLOT( slotPreviousTab() ), coll, "tabs_left" );
tabLeft->setEnabled( false );
tabRight->setEnabled( false );
- nickComplete = new KAction( i18n( "Nic&k Completion" ), TQString(), 0, TQT_TQOBJECT(this), TQT_SLOT( slotNickComplete() ), coll , "nick_compete");
+ nickComplete = new TDEAction( i18n( "Nic&k Completion" ), TQString(), 0, TQT_TQOBJECT(this), TQT_SLOT( slotNickComplete() ), coll , "nick_compete");
nickComplete->setShortcut( TQKeySequence( Key_Tab ) );
- tabDetach = new KAction( i18n( "&Detach Chat" ), TQString::fromLatin1( "tab_breakoff" ), 0,
+ tabDetach = new TDEAction( i18n( "&Detach Chat" ), TQString::fromLatin1( "tab_breakoff" ), 0,
TQT_TQOBJECT(this), TQT_SLOT( slotDetachChat() ), coll, "tabs_detach" );
tabDetach->setEnabled( false );
- actionDetachMenu = new KActionMenu( i18n( "&Move Tab to Window" ), TQString::fromLatin1( "tab_breakoff" ), coll, "tabs_detachmove" );
+ actionDetachMenu = new TDEActionMenu( i18n( "&Move Tab to Window" ), TQString::fromLatin1( "tab_breakoff" ), coll, "tabs_detachmove" );
actionDetachMenu->setDelayed( false );
connect ( actionDetachMenu->popupMenu(), TQT_SIGNAL(aboutToShow()), this, TQT_SLOT(slotPrepareDetachMenu()) );
connect ( actionDetachMenu->popupMenu(), TQT_SIGNAL(activated(int)), this, TQT_SLOT(slotDetachChat(int)) );
- actionTabPlacementMenu = new KActionMenu( i18n( "&Tab Placement" ), coll, "tabs_placement" );
+ actionTabPlacementMenu = new TDEActionMenu( i18n( "&Tab Placement" ), coll, "tabs_placement" );
connect ( actionTabPlacementMenu->popupMenu(), TQT_SIGNAL(aboutToShow()), this, TQT_SLOT(slotPreparePlacementMenu()) );
connect ( actionTabPlacementMenu->popupMenu(), TQT_SIGNAL(activated(int)), this, TQT_SLOT(slotPlaceTabs(int)) );
@@ -354,15 +354,15 @@ void KopeteChatWindow::initActions(void)
KStdAction::copy( TQT_TQOBJECT(this), TQT_SLOT(slotCopy()), coll);
KStdAction::paste( TQT_TQOBJECT(this), TQT_SLOT(slotPaste()), coll);
- new KAction( i18n( "Set Default &Font..." ), TQString::fromLatin1( "charset" ), 0, TQT_TQOBJECT(this), TQT_SLOT( slotSetFont() ), coll, "format_font" );
- new KAction( i18n( "Set Default Text &Color..." ), TQString::fromLatin1( "pencil" ), 0, TQT_TQOBJECT(this), TQT_SLOT( slotSetFgColor() ), coll, "format_fgcolor" );
- new KAction( i18n( "Set &Background Color..." ), TQString::fromLatin1( "fill" ), 0, TQT_TQOBJECT(this), TQT_SLOT( slotSetBgColor() ), coll, "format_bgcolor" );
+ new TDEAction( i18n( "Set Default &Font..." ), TQString::fromLatin1( "charset" ), 0, TQT_TQOBJECT(this), TQT_SLOT( slotSetFont() ), coll, "format_font" );
+ new TDEAction( i18n( "Set Default Text &Color..." ), TQString::fromLatin1( "pencil" ), 0, TQT_TQOBJECT(this), TQT_SLOT( slotSetFgColor() ), coll, "format_fgcolor" );
+ new TDEAction( i18n( "Set &Background Color..." ), TQString::fromLatin1( "fill" ), 0, TQT_TQOBJECT(this), TQT_SLOT( slotSetBgColor() ), coll, "format_bgcolor" );
- historyUp = new KAction( i18n( "Previous History" ), TQString(), 0,
+ historyUp = new TDEAction( i18n( "Previous History" ), TQString(), 0,
TQT_TQOBJECT(this), TQT_SLOT( slotHistoryUp() ), coll, "history_up" );
historyUp->setShortcut( TQKeySequence(CTRL + Key_Up) );
- historyDown = new KAction( i18n( "Next History" ), TQString(), 0,
+ historyDown = new TDEAction( i18n( "Next History" ), TQString(), 0,
TQT_TQOBJECT(this), TQT_SLOT( slotHistoryDown() ), coll, "history_down" );
historyDown->setShortcut( TQKeySequence(CTRL + Key_Down) );
@@ -371,14 +371,14 @@ void KopeteChatWindow::initActions(void)
KStdAction::showMenubar( TQT_TQOBJECT(this), TQT_SLOT(slotViewMenuBar()), coll );
- membersLeft = new KToggleAction( i18n( "Place to Left of Chat Area" ), TQString(), 0,
+ membersLeft = new TDEToggleAction( i18n( "Place to Left of Chat Area" ), TQString(), 0,
TQT_TQOBJECT(this), TQT_SLOT( slotViewMembersLeft() ), coll, "options_membersleft" );
- membersRight = new KToggleAction( i18n( "Place to Right of Chat Area" ), TQString(), 0,
+ membersRight = new TDEToggleAction( i18n( "Place to Right of Chat Area" ), TQString(), 0,
TQT_TQOBJECT(this), TQT_SLOT( slotViewMembersRight() ), coll, "options_membersright" );
- toggleMembers = new KToggleAction( i18n( "Show" ), TQString(), 0,
+ toggleMembers = new TDEToggleAction( i18n( "Show" ), TQString(), 0,
TQT_TQOBJECT(this), TQT_SLOT( slotToggleViewMembers() ), coll, "options_togglemembers" );
toggleMembers->setCheckedState(i18n("Hide"));
- toggleAutoSpellCheck = new KToggleAction( i18n( "Automatic Spell Checking" ), TQString(), 0,
+ toggleAutoSpellCheck = new TDEToggleAction( i18n( "Automatic Spell Checking" ), TQString(), 0,
TQT_TQOBJECT(this), TQT_SLOT( toggleAutoSpellChecking() ), coll, "enable_auto_spell_check" );
toggleAutoSpellCheck->setChecked( true );
@@ -386,7 +386,7 @@ void KopeteChatWindow::initActions(void)
actionSmileyMenu->setDelayed( false );
connect(actionSmileyMenu, TQT_SIGNAL(activated(const TQString &)), this, TQT_SLOT(slotSmileyActivated(const TQString &)));
- actionContactMenu = new KActionMenu(i18n("Co&ntacts"), coll, "contacts_menu" );
+ actionContactMenu = new TDEActionMenu(i18n("Co&ntacts"), coll, "contacts_menu" );
actionContactMenu->setDelayed( false );
connect ( actionContactMenu->popupMenu(), TQT_SIGNAL(aboutToShow()), this, TQT_SLOT(slotPrepareContactMenu()) );
@@ -981,7 +981,7 @@ void KopeteChatWindow::slotPrepareContactMenu(void)
for ( contact = m_them.first(); contact; contact = m_them.next() )
{
- KPopupMenu *p = contact->popupMenu();
+ TDEPopupMenu *p = contact->popupMenu();
connect ( actionContactMenu->popupMenu(), TQT_SIGNAL(aboutToHide()),
p, TQT_SLOT(deleteLater() ) );
@@ -993,7 +993,7 @@ void KopeteChatWindow::slotPrepareContactMenu(void)
//FIXME: This number should be a config option
if( ++contactCount == 15 && contact != m_them.getLast() )
{
- KActionMenu *moreMenu = new KActionMenu( i18n("More..."),
+ TDEActionMenu *moreMenu = new TDEActionMenu( i18n("More..."),
TQString::fromLatin1("folder_open"), TQT_TQOBJECT(contactsMenu) );
connect ( actionContactMenu->popupMenu(), TQT_SIGNAL(aboutToHide()),
moreMenu, TQT_SLOT(deleteLater() ) );
@@ -1176,7 +1176,7 @@ void KopeteChatWindow::closeEvent( TQCloseEvent * e )
KopeteApplication *app = static_cast<KopeteApplication *>( kapp );
if ( KopetePrefs::prefs()->showTray() && !app->isShuttingDown() && !app->sessionSaving() ) {
// hide();
// BEGIN of code borrowed from KMainWindow::closeEvent
// Save settings if auto-save is enabled, and settings have changed
if ( settingsDirty() && autoSaveSettings() )
saveAutoSaveSettings();
@@ -1184,10 +1184,10 @@ void KopeteChatWindow::closeEvent( TQCloseEvent * e )
if ( queryClose() ) {
e->accept();
}
// END of code borrowed from KMainWindow::closeEvent
}
else
- KMainWindow::closeEvent( e );
+ TDEMainWindow::closeEvent( e );
}
void KopeteChatWindow::slotConfKeys()
@@ -1176,7 +1176,7 @@ void KopeteChatWindow::closeEvent( TQCloseEvent * e )
if ( KopetePrefs::prefs()->showTray() && !app->isShuttingDown() && !app->sessionSaving() ) {
// hide();
- // BEGIN of code borrowed from KMainWindow::closeEvent
+ // BEGIN of code borrowed from TDEMainWindow::closeEvent
// Save settings if auto-save is enabled, and settings have changed
if ( settingsDirty() && autoSaveSettings() )
@@ -1184,10 +1184,10 @@ void KopeteChatWindow::closeEvent( TQCloseEvent * e )
e->accept();
}
- // END of code borrowed from KMainWindow::closeEvent
+ // END of code borrowed from TDEMainWindow::closeEvent
}
else